@@ -17,36 +17,33 @@
 // with Gnome Weather; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-const Gdk = imports.gi.Gdk;
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const Lang = imports.lang;
-const Gc = imports.gi.Gc;
+const {Gc, Gdk, Gio, GLib, GObject} = imports.gi;
+
 const Util = imports.util;
 
-const MAX_SEARCH_RESULTS = 100
+const MAX_SEARCH_RESULTS = 100;
 
 const SearchProviderInterface = Gio.resources_lookup_data('/org/gnome/shell/ShellSearchProvider2.xml', 0).toArray().toString();
 
-const SearchProvider = new Lang.Class({
+const SearchProvider = GObject.registerClass({
     Name: 'CharactersSearchProvider',
-
-    _init: function(application) {
+}, class SearchProvider extends GObject.Object {
+    _init(application) {
         this._app = application;
 
         this._impl = Gio.DBusExportedObject.wrapJSObject(SearchProviderInterface, this);
         this._cancellable = new Gio.Cancellable();
-    },
+    }
 
-    export: function(connection, path) {
+    export(connection, path) {
         return this._impl.export(connection, path);
-    },
+    }
 
-    unexport: function(connection) {
+    unexport(connection) {
         return this._impl.unexport_from_connection(connection);
-    },
+    }
 
-    _runQuery: function(keywords, invocation) {
+    _runQuery(keywords, invocation) {
         this._cancellable.cancel();
         this._cancellable.reset();
 
@@ -57,31 +54,31 @@ const SearchProvider = new Lang.Class({
         context.search(
             MAX_SEARCH_RESULTS,
             this._cancellable,
-            Lang.bind(this, function(source_object, res, user_data) {
+            (source_object, res, user_data) => {
                 let characters = [];
                 try {
                     let result = context.search_finish(res);
                     characters = Util.searchResultToArray(result);
                 } catch (e) {
-                    log("Failed to search by keywords: " + e.message);
+                    log(`Failed to search by keywords: ${e.message}`);
                 }
                 invocation.return_value(new GLib.Variant('(as)', [characters]));
 
                 this._app.release();
-            }));
-    },
+            });
+    }
 
-    GetInitialResultSetAsync: function(params, invocation) {
+    GetInitialResultSetAsync(params, invocation) {
         this._app.hold();
         this._runQuery(params[0], invocation);
-    },
+    }
 
-    GetSubsearchResultSetAsync: function(params, invocation) {
+    GetSubsearchResultSetAsync(params, invocation) {
         this._app.hold();
         this._runQuery(params[1], invocation);
-    },
+    }
 
-    GetResultMetas: function(identifiers) {
+    GetResultMetas(identifiers) {
         this._app.hold();
 
         let ret = [];
@@ -109,14 +106,14 @@ const SearchProvider = new Lang.Class({
         this._app.release();
 
         return ret;
-    },
+    }
 
-    ActivateResult: function(id, terms, timestamp) {
+    ActivateResult(id, terms, timestamp) {
         let clipboard = Gc.gtk_clipboard_get();
         clipboard.set_text(id, -1);
-    },
+    }
 
-    _getPlatformData: function(timestamp) {
+    _getPlatformData(timestamp) {
         let display = Gdk.Display.get_default();
         let context = display.get_app_launch_context();
         context.set_timestamp(timestamp);
@@ -124,9 +121,9 @@ const SearchProvider = new Lang.Class({
         let app = Gio.DesktopAppInfo.new('org.gnome.Characters.desktop');
         let id = context.get_startup_notify_id(app, []);
         return {'desktop-startup-id': new GLib.Variant('s', id) };
-    },
+    }
 
-    _activateAction: function(action, parameter, timestamp) {
+    _activateAction(action, parameter, timestamp) {
         let wrappedParam;
         if (parameter)
             wrappedParam = [parameter];
@@ -141,18 +138,18 @@ const SearchProvider = new Lang.Class({
                                                               this._getPlatformData(timestamp)]),
                               null,
                               Gio.DBusCallFlags.NONE,
-                              -1, null, Lang.bind(this, function(connection, result) {
+                              -1, null, (connection, result) => {
                                   try {
                                       connection.call_finish(result);
                                   } catch(e) {
-                                      log('Failed to launch application: ' + e.message);
+                                      log(`Failed to launch application: ${e.message}`);
                                   }
 
                                   this._app.release();
-                              }));
-    },
+                              });
+    }
 
-    LaunchSearch: function(terms, timestamp) {
+    LaunchSearch(terms, timestamp) {
         this._activateAction('search', new GLib.Variant('as', terms),
                              timestamp);
     }
